@extends ('layouts.patient')

@section('inner-content')
    <div>

        {{-- CARE PLAN START --}}
        <?php $infoLines = json_decode($patient->info_lines);?>
        <?php $infoLines = !$infoLines ? [] : $infoLines; ?>

	<?php
		function getVal($object, $prop){
			if(isset($object->$prop)){
				return $object->$prop;
			}else{
				return '';
			}
        }

        $vitalMap = [
                'heightInches' => 'Ht. (in.)',
				'weightPounds' => 'Wt. (lbs.)',
				'temperatureF' => 'Temp. (F)',
				'pulseRatePerMinute' => 'Pulse',
				'respirationRatePerMinute' => 'Resp.',
				'pulseOx' => 'Pulse Ox.',
				'systolicBP' => 'SBP',
				'diastolicBP' => 'DBP',
                'smokingStatus' => 'Smoking Status'
        ];

        $vitalLabels = ['Ht. (in.)','Wt. (lbs.)','Temp. (F)','Pulse','Resp.','Pulse Ox.','SBP','DBP','Smoking Status'];

        $vitalValues = [];

        foreach($vitalLabels as $l){
            $vitalValues[$l] = [
                'value' => null,
                'effectiveDate' => null
            ];
        }

        foreach($patient->measurements as $measurement) {
            if(!empty($measurement->label) && in_array($measurement->label, $vitalLabels)){
                $vitalValues[$measurement->label] = [
                    'value'=>$measurement->value,
                    'effectiveDate' => $measurement->effective_date
                ];
            }
        }

	?>

        <div class="row">
            <div class="col-6">

                {{-- appointments --}}
                <div class="mt-2 pb-1">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Appointments</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <span moe>
                            <a start show>Add</a>
                            <form url="/api/appointment/create" class="mcp-theme-1">
                                <input type="hidden" name="clientUid" value="{{$patient->uid}}">
                                <input type="hidden" name="title" value="MCP Appointment">
                                <div class="mb-2">
                                    <label class="text-secondary text-sm">Pro</label>
                                    <select name="proUid" class="form-control form-control-sm">
                                        <option value=""> --select-- </option>
                                        @foreach($pros as $iPro)
                                            <option value="{{$iPro->uid}}" {{ $iPro->uid === $pro->uid ? 'selected' : '' }}>{{$iPro->displayName()}}</option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <label class="text-secondary text-sm">Date</label>
                                    <input type="date" name="date" min="{{ date('Y-m-d') }}" value="{{ date('Y-m-d') }}"
                                           class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <label class="text-secondary text-sm">Start Time</label>
                                    <input type="time" name="startTime" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <label class="text-secondary text-sm">End Time</label>
                                    <input type="time" name="endTime" class="form-control form-control-sm">
                                </div>
                                <div>
                                    <button submit class="btn btn-sm btn-primary mr-1">Submit</button>
                                    <button cancel class="btn btn-sm btn-default border">Cancel</button>
                                </div>
                            </form>
                        </span>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($patient->appointments as $appointment)
                            <tr>
                                <td class="text-black p-0 border-0">
                                    <div class="pb-0">
                                        <span relative moe>
                                            <a class="on-hover-opaque" start show title="Update">
                                                <i class="font-size-11 fa fa-edit text-primary"></i>
                                            </a>
                                            <form url="/api/appointment/update">
                                                <input type="hidden" name="uid" value="{{ $appointment->uid }}">
                                                <input type="hidden" name="title" value="MCP Appointment">
                                                <div class="mb-2">
                                                    <label class="text-secondary text-sm">Pro</label>
                                                    <select name="proUid" class="form-control form-control-sm">
                                                        <option value=""> --select-- </option>
                                                        @foreach($pros as $iPro)
                                                            <option <?= $appointment->pro->uid === $iPro->uid ? 'selected' : '' ?>
                                                                    value="{{$iPro->uid}}">{{$iPro->displayName()}}</option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                                <div class="mb-2">
                                                    <label class="text-secondary text-sm">Date</label>
                                                    <input autofocus type="date" name="date" min="{{ date('Y-m-d') }}"
                                                           value="{{ date("Y-m-d", strtotime($appointment->start_time)) }}" class="form-control form-control-sm">
                                                </div>
                                                <div class="mb-2">
                                                    <label class="text-secondary text-sm">Start Time</label>
                                                    <input type="time" name="startTime" class="form-control form-control-sm"
                                                           value="{{ date("H:i:s", strtotime($appointment->start_time)) }}">
                                                </div>
                                                <div class="mb-2">
                                                    <label class="text-secondary text-sm">End Time</label>
                                                    <input type="time" name="endTime" class="form-control form-control-sm"
                                                           value="{{ date("H:i:s", strtotime($appointment->end_time)) }}">
                                                </div>
                                                <div>
                                                    <button submit class="btn btn-sm btn-primary mr-1">Submit</button>
                                                    <button cancel class="btn btn-sm btn-default border">Cancel</button>
                                                </div>
                                            </form>
                                        </span>
                                        {{ friendly_date_time($appointment->start_time, false) }}, {{ friendly_time($appointment->start_time) }}
                                        &nbsp;/&nbsp;
                                        {{--<span class="d-inline-block ml- 2 text-secondary">{{ $appointment->title }}</span>
                                        &nbsp;/&nbsp;--}}
                                        <b class="mr-1">{{$appointment->pro->displayName()}}</b>
                                        <span class="text-secondary text-sm">({{ $appointment->status }})</span>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                        @if(!$patient->appointments || count($patient->appointments) === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No appointments
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

                {{-- vitals --}}
                <div class="mt-2 pb-1">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Vitals</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Update</a>
                            <form url="/api/measurement/updateVitals">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <div class="mb-2">
                                    Ht. (in.)<br>
                                    <input type="text" class="form-control form-control-sm" name="heightInches" value="{{$vitalValues['Ht. (in.)']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    Wt. (lbs.)<br>
                                    <input type="text" class="form-control form-control-sm" name="weightPounds" value="{{$vitalValues['Wt. (lbs.)']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    <label for="" class="control-label mb-0">Temp. (F)</label>
                                    Temp. (F)<br/>
                                    <input type="text" class="form-control form-control-sm" name="temperatureF" value="{{$vitalValues['Temp. (F)']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    Pulse<br/>
                                    <input type="text" class="form-control form-control-sm" name="pulseRatePerMinute" value="{{$vitalValues['Pulse']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    Resp.<br/>
                                    <input type="text" class="form-control form-control-sm" name="respirationRatePerMinute" value="{{$vitalValues['Resp.']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    Pulse Ox.<br/>
                                    <input type="text" class="form-control form-control-sm" name="pulseOx" value="{{$vitalValues['Pulse Ox.']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    SBP<br/>
                                    <input type="text" class="form-control form-control-sm" name="systolicBP" value="{{$vitalValues['SBP']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    DBP<br/>
                                    <input type="text" class="form-control form-control-sm" name="diastolicBP" value="{{$vitalValues['DBP']['value']}}" placeholder="">
                                </div>
				                <div class="mb-2">
                                    Smoking Status<br/>
                                    <input type="text" class="form-control form-control-sm" name="smokingStatus" value="{{$vitalValues['Smoking Status']['value']}}" placeholder="">
                                </div>

                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/measurements">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                            @foreach($vitalLabels as $label)
                                <tr>
                                    <td class="text-black p-0 border-0">
                                        <div class="d-flex align-items-center">
                                            <div moe class="mr-2">
                                                <a class="on-hover-opaque" start show title="Update">
                                                    <i class="font-size-11 fa fa-edit text-primary"></i>
                                                </a>
                                                <form url="/api/measurement/create">
                                                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                    <div class="mb-2">
                                                        <input type="text" class="form-control form-control-sm" name="label" value="{{ $label }}" placeholder="Type">
                                                    </div>
                                                    <div class="mb-2">
                                                        <input autofocus type="text" class="form-control form-control-sm" name="value" value="{{ $vitalValues[$label]['value'] }}" placeholder="Value">
                                                    </div>
                                                    <div class="mb-2">
                                                        <input type="date" class="form-control form-control-sm" name="effectiveDate" max="{{ date('Y-m-d') }}" value="{{ date('Y-m-d') }}">
                                                    </div>
                                                    <div class="d-flex align-items-center">
                                                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                    </div>
                                                </form>
                                            </div>
                                            <span>{{ $label }}:</span>
                                            <span class="font-weight-bold ml-1">{{ $vitalValues[$label]['value'] }}</span>
                                            <span class="font-weight-normal text-secondary ml-2 text-sm">(as on {{ friendly_date_time($vitalValues[$label]['effectiveDate'], false) }})</span>
                                        </div>
                                    </td>
                                </tr>
                        @endforeach
                        @if(!$patient->measurements || !count($patient->measurements) === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

                {{-- measurements --}}
                <div class="mt-2 pb-1">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Measurements</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/measurement/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <div class="mb-2">
                                    <input autofocus type="text" class="form-control form-control-sm" name="label" value="" placeholder="Type">
                                </div>
                                <div class="mb-2">
                                    <input type="text" class="form-control form-control-sm" name="value" value="" placeholder="Value">
                                </div>
                                <div class="mb-2">
                                    <input type="date" class="form-control form-control-sm" name="effectiveDate" max="{{ date('Y-m-d') }}" value="{{ date('Y-m-d') }}">
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/measurements">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($patient->measurements as $measurement)
                            @if(!empty($measurement->label) && !in_array($measurement->label, $vitalLabels))
                                <tr>
                                    <td class="text-black p-0 border-0">
                                        <div class="d-flex align-items-center">
                                            <div moe relative class="mr-2">
                                                <a class="on-hover-opaque" start show title="Delete">
                                                    <i class="font-size-11 fa fa-trash-alt text-danger"></i>
                                                </a>
                                                <form url="/api/measurement/remove">
                                                    <input type="hidden" name="uid" value="{{ $measurement->uid }}">
                                                    <p class="small min-width-200px">Are you sure you want to delete this entry?</p>
                                                    <div class="d-flex align-items-center">
                                                        <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                    </div>
                                                </form>
                                            </div>
                                            <div moe class="mr-2">
                                                <a class="on-hover-opaque" start show title="Update">
                                                    <i class="font-size-11 fa fa-edit text-primary"></i>
                                                </a>
                                                <form url="/api/measurement/create">
                                                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                    <div class="mb-2">
                                                        <input type="text" class="form-control form-control-sm" name="label" value="{{ $measurement->label }}" placeholder="Type">
                                                    </div>
                                                    <div class="mb-2">
                                                        <input autofocus type="text" class="form-control form-control-sm" name="value" value="{{ $measurement->value }}" placeholder="Value">
                                                    </div>
                                                    <div class="mb-2">
                                                        <input type="date" class="form-control form-control-sm" name="effectiveDate" max="{{ date('Y-m-d') }}" value="{{ date('Y-m-d') }}">
                                                    </div>
                                                    <div class="d-flex align-items-center">
                                                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                    </div>
                                                </form>
                                            </div>
                                            <span>{{ $measurement->label }}:</span>
                                            <span class="font-weight-bold ml-1">{{ $measurement->value }}</span>
                                            <span class="font-weight-normal text-secondary ml-2 text-sm">(as on {{ friendly_date_time($measurement->effective_date, false) }})</span>
                                        </div>
                                    </td>
                                </tr>
                            @endif
                        @endforeach
                        @if(!$patient->measurements || !count($patient->measurements) === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

                {{-- allergies --}}
                <div class="mt-2 pb-1">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Allergies</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="allergy">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="Allergy"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>

                        <div moe>
                            <a start show class="">Multi</a>
                            <form url="/api/clientInfoLine/createMultiple">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="allergy">
                                <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Allergies"></textarea></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/allergies">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        <?php $itemCount = 0;
                        ?>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "allergy")
                                @foreach ($lines as $line)
                                    <?php $itemCount++; ?>
                                    <tr>
                                        <td class="text-black p-0 border-0">
                                            <div class="d-flex">
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete">
                                                        <i class="font-size-11 fa fa-trash-alt text-danger"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="category" value="allergy">
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm" name="contentText" placeholder="Allergy" value="{{$line->contentText}}">
                                                        </div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="font-weight-bold">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        @if($itemCount === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

                {{-- rx --}}
                <div class="mt-2 pb-1" rx-section>
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Current Medications</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="rx">
                                <div class="mb-2">
                                    <input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="Medication">
                                </div>
                                <div class="mb-2">
                                    <input type="text" class="form-control form-control-sm" name="strength" value="" placeholder="Strength/Form">
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" type="button" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" type="button" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>

                        <div moe>
                            <a start show class="">Multi</a>
                            <form url="/api/clientInfoLine/createMultiple">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="rx">
                                <div class="mb-2">
                                    <textarea class="form-control form-control-sm" rows="8"
                                              name="contentTexts" value=""
                                              placeholder="Medications"></textarea>
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/medications">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        <?php $itemCount = 0; ?>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "rx")
                                @foreach ($lines as $line)
                                    <?php $itemCount++; ?>
                                    <tr>
                                        <td class="text-black p-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete">
                                                        <i class="font-size-11 fa fa-trash-alt text-danger"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="rx">
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm"
                                                                   name="contentText"
                                                                   placeholder="Medication"
                                                                   value="{{$line->contentText}}"></div>
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm" name="strength"
                                                                   value="{{getVal($line->contentDetail, "strength") }}" placeholder="Strength/Form">
                                                        </div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" type="button" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" type="button" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span>
                                                    <span class="font-weight-bold">{{$line->contentText}}</span>
                                                    @if(!empty(getVal($line->contentDetail, "strength")))
                                                    <span class="text-secondary">/</span>
                                                    <span>{{getVal($line->contentDetail, "strength") }}</span>
                                                    @endif
                                                </span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        @if($itemCount === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

            </div>
            <div class="col-6">

                {{-- dx --}}
                <div class="mt-2 pb-1">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Current Problems / Focus Areas</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="dx">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="ICD" value="" placeholder="ICD"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="Title"></div>
                                <div class="mb-2">
                                    <select name="Chronic or Acute" class="form-control form-control-sm pl-1">
                                        <option>Chronic or Acute (select one)</option>
                                        <option value="Chronic">Chronic</option>
                                        <option value="Acute">Acute</option>
                                    </select>
                                </div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Prognosis" value="" placeholder="Prognosis"></div>
                                <div class="mb-2"><textarea type="text" class="form-control form-control-sm" name="Treatment Goal" value="" placeholder="Treatment Goal"></textarea></div>
                                <div class="mb-2"><textarea type="text" class="form-control form-control-sm" name="Treatment Plan" value="" placeholder="Treatment Plan"></textarea></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" type="button" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" type="button" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>

                        <div moe>
                            <a start show class="">Multi</a>
                            <form url="/api/clientInfoLine/createMultiple">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="dx">
                                <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Dx & Focus Areas"></textarea></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/dx-and-focus-areas">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        <?php $itemCount = 0; ?>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "dx")
                                @foreach ($lines as $line)
                                    <?php $itemCount++; ?>
                                    <tr>
                                        <td class="text-black p-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete">
                                                        <i class="font-size-11 fa fa-trash-alt text-danger"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="dx">
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm" name="ICD" value="{{ getVal($line->contentDetail, "ICD") }}" placeholder="ICD">
                                                        </div>
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="Title">
                                                        </div>
                                                        <div class="mb-2">
                                                            <select name="Chronic or Acute" class="form-control form-control-sm pl-1">
                                                                <option>Chronic or Acute (select one)</option>
                                                                <option {{ getVal($line->contentDetail, ("Chronic or Acute")) === 'Chronic' ? 'selected' : '' }} value="Chronic">Chronic</option>
                                                                <option {{ getVal($line->contentDetail, ("Chronic or Acute")) === 'Acute' ? 'selected' : '' }} value="Acute">Acute</option>
                                                            </select>
                                                        </div>
                                                        <div class="mb-2">
                                                            <input type="text" class="form-control form-control-sm" name="Prognosis" value="{{ getVal($line->contentDetail, "Prognosis") }}" placeholder="Prognosis">
                                                        </div>
                                                        <div class="mb-2">
                                                            <textarea type="text" class="form-control form-control-sm" name="Treatment Goal" placeholder="Treatment Goal">{{ getVal($line->contentDetail, "Treatment Goal") }}</textarea>
                                                        </div>
                                                        <div class="mb-2">
                                                            <textarea type="text" class="form-control form-control-sm" name="Treatment Plan" placeholder="Treatment Plan">{{ getVal($line->contentDetail, "Treatment Plan") }}</textarea>
                                                        </div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" type="button" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" type="button" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <div>
                                                    <span class="font-weight-bold">{{$line->contentText}}</span>
                                                    @if(!empty(getVal($line->contentDetail, "Chronic or Acute")))
                                                    <span class="text-secondary mx-1">/</span>
                                                    <span class="text-secondary">{{ getVal($line->contentDetail, "Chronic or Acute") }}</span>
                                                    @endif
                                                    @if(!empty(getVal($line->contentDetail, "ICD")))
                                                    <span class="text-secondary mx-1">/</span>
                                                    <span class="text-secondary">ICD: {{ getVal($line->contentDetail, "ICD") ? getVal($line->contentDetail, "ICD") : '-' }}</span>
                                                    @endif
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        @if($itemCount === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>

                <div class="mt-2">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">History</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/history">
                            View All
                        </a>
                    </div>
                </div>

                {{-- history_medical --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Medical</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_medical">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_medical">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_medical")
                                @foreach ($lines as $line)
                                    <tr>
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_medical">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_surgical --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Surgical</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_surgical">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_surgical">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>

                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_surgical")
                                @foreach ($lines as $line)
                                    <tr>
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_surgical">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_family --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Family</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_family">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_family">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>

                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_family")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_family">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_social --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Social</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_social">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>


                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_social">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>
</div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_social")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_social">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_ob_and_preg --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">OB & Pregnancy</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_ob_and_preg">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_ob_and_preg">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>

                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_ob_and_preg")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_ob_and_preg">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_hospitalizations_procedures --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Hospitalizations / Procedures</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_hospitalizations_procedures">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_hospitalizations_procedures">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>

                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_hospitalizations_procedures")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_hospitalizations_procedures">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_screenings --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Screenings</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_screenings">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="history_screenings">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Lines..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>


                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_screenings")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_screenings">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_colonoscopy --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Colonoscopy</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_colonoscopy">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_colonoscopy")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_colonoscopy">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                {{-- history_mammogram --}}
                <div class="mt-2">
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold">Mammogram</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="history_mammogram">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="History"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "history_mammogram")
                                @foreach ($lines as $line)
                                    <tr>
                                        {{--<td class="px-2">{{$category}}</td>--}}
                                        <td class="pl-4 py-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete"><i class="font-size-11 fa fa-trash-alt text-danger"></i></a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="history_mammogram">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="History"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="">{{$line->contentText}}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>

                <div class="mt-4">
                    <div class="d-flex align-items-center mb-2 py-2 border-top border-bottom">
                        <h6 class="my-0 font-weight-bold text-secondary">Care Team</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/clientInfoLine/create">
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="category" value="care_team">
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="Name"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Specialty" value="" placeholder="Specialty"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Organization" value="" placeholder="Organization"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Phone" value="" placeholder="Phone"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Fax" value="" placeholder="Fax"></div>
                                <div class="mb-2"><input type="date" class="form-control form-control-sm" name="Next Appointment" value="" placeholder="Next Appointment"></div>
                                <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Memo" value="" placeholder="Memo"></div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>

                         <span class="mx-2 text-secondary">|</span>

            <div moe>
                <a start show class="">Multi</a>
                <form url="/api/clientInfoLine/createMultiple">
                    <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                    <input type="hidden" name="category" value="care_team">
                    <div class="mb-2"><textarea class="form-control form-control-sm" rows="8" name="contentTexts" value="" placeholder="Care Team Members..."></textarea></div>
                    <div class="d-flex align-items-center">
                        <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                        <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                    </div>
                </form>
            </div>

                        <span class="mx-2 text-secondary">|</span>
                        <a start show class="py-0 font-weight-normal"
                           href="/patients/view/{{ $patient->uid }}/care-team">
                            View All
                        </a>
                    </div>
                    <table class="table table-sm border-0 m-0">
                        <tbody>
                        <?php $itemCount = 0; ?>
                        @foreach($infoLines as $category => $lines)
                            @if($category === "care_team")
                                @foreach ($lines as $line)
                                    <?php $itemCount++; ?>
                                    <tr>
                                        <td class="text-black p-0 border-0">
                                            <div class="d-flex">
                                                <span moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Delete">
                                                        <i class="font-size-11 fa fa-trash-alt text-danger"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/remove">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <p class="small">Are you sure you want to delete this entry?</p>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-danger mr-2" submit>Delete</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </span>
                                                <div moe relative class="mr-2">
                                                    <a class="on-hover-opaque" start show title="Edit">
                                                        <i class="font-size-11 fa fa-edit"></i>
                                                    </a>
                                                    <form url="/api/clientInfoLine/updateContent">
                                                        <input type="hidden" name="uid" value="{{ $line->uid }}">
                                                        <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                                        <input type="hidden" name="category" value="care_team">
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="contentText" value="{{$line->contentText}}" placeholder="Name"></div>
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Specialty" value="{{ getVal($line->contentDetail, 'Specialty') }}" placeholder="Specialty"></div>
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Organization" value="{{getVal($line->contentDetail, 'Organization') }}" placeholder="Organization"></div>
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Phone" value="{{getVal($line->contentDetail, 'Phone') }}" placeholder="Phone"></div>
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Fax" value="{{getVal($line->contentDetail, 'Fax') }}" placeholder="Fax"></div>
                                                        <div class="mb-2"><input type="date" class="form-control form-control-sm" name="Next Appointment" value="{{getVal($line->contentDetail, 'Next Appointment') }}" placeholder="Next Appointment"></div>
                                                        <div class="mb-2"><input type="text" class="form-control form-control-sm" name="Memo" value="{{getVal($line->contentDetail, 'Memo') }}" placeholder="Memo"></div>
                                                        <div class="d-flex align-items-center">
                                                            <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                            <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                                        </div>
                                                    </form>
                                                </div>
                                                <span class="font-weight-bold">{{$line->contentText}}</span>
                                                <span class="text-secondary mx-1">/</span>
                                                <span class="text-secondary">{{ getVal($line->contentDetail, 'Specialty') }}</span>
                                                <span class="text-secondary mx-1">/</span>
                                                <span class="text-secondary">Next Apt: {{ getVal($line->contentDetail, 'Next Appointment') ? $line->contentDetail('Next Appointment') : '-' }}</span>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        @endforeach
                        @if($itemCount === 0)
                            <tr>
                                <td class="text-secondary p-0 border-0">
                                    No items to show
                                </td>
                            </tr>
                        @endif
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div class="row my-3">
            <div class="col-12">
                {{-- erx --}}
                <div  class="mb-2 py-2 border-top">
                    <style>
                        td.fit {
                            width:1%;
                            white-space:nowrap;
                        }
                    </style>
                    <div class="d-flex align-items-center pb-2">
                        <h6 class="my-0 font-weight-bold text-secondary">ERx</h6>
                        <span class="mx-2 text-secondary">|</span>
                        <div moe>
                            <a start show class="py-0 font-weight-normal">Add</a>
                            <form url="/api/actionItem/create" wide>
                                <input type="hidden" name="clientUid" value="{{ $patient->uid }}">
                                <input type="hidden" name="prescriberProUid" value="{{ $pro->uid }}">
                                <input type="hidden" name="category" value="DRUG">
                                <div class="mb-2">
                                    <label for="" class="control-label text-sm text-secondary mb-1">Pharmacy</label>
                                    <select name="toFacilityUid"
                                            class="form-control form-control-sm">
                                        <option value="">-- Pharmacy --</option>
                                        @foreach ($facilities as $facility)
                                            <option value="{{$facility->uid}}">{{$facility->name}}</option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <input type="text" class="form-control form-control-sm" name="contentText" value="" placeholder="Title *" required>
                                </div>
                                <div class="mb-2">
                                    <input type="text" class="form-control form-control-sm" name="contentDetail" value="" placeholder="Directions">
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    <table class="table table-sm table-bordered mb-0" style="table-layout: fixed">
                        <thead>
                        <tr>
                            <th class="px-2 text-secondary border-bottom-0 w-25">Prescription</th>
                            <th class="px-2 text-secondary border-bottom-0 fit">Created</th>
                            <th class="px-2 text-secondary border-bottom-0 fit">Status</th>
                            <th class="px-2 text-secondary border-bottom-0 fit">Pharmacy</th>
                            <th class="px-2 text-secondary border-bottom-0">&nbsp;</th>
                        </tr>
                        </thead>
                        <tbody>
                        <?php $prevItemType = false; ?>
                        @foreach($patient->actionItems as $item)
                            @if($item->action_item_category === 'DRUG')
                                <tr>
                                    <td class="px-2">
                                        {{$item->content_text}}
                                        <span moe>
                                        <a start show class="on-hover-opaque"><i class="fa fa-edit"></i></a>
                                        <form url="/api/actionItem/updateContent" wide>
                                            <input type="hidden" name="uid" value="{{ $item->uid }}">
                                            <div class="mb-2">
                                                <input type="text" class="form-control form-control-sm" name="contentText" value="{{ $item->content_text }}" placeholder="Title *" required>
                                            </div>
                                            <div class="mb-2">
                                                <input type="text" class="form-control form-control-sm" name="contentDetail" value="{{ $item->content_detail }}" placeholder="Details">
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </span>
                                        <div class="text-sm text-secondary">{{$item->content_detail}}</div>
                                    </td>
                                    <td class="px-2">{{friendly_date_time($item->created_at, false)}}</td>
                                    <td class="px-2">
                                        {{ucwords($item->status_category)}}
                                        <span moe>
                                        <a start show class="on-hover-opaque"><i class="fa fa-edit"></i></a>
                                        <form url="/api/actionItem/updateStatus">
                                            <input type="hidden" name="uid" value="{{ $item->uid }}">
                                            <div class="mb-2">
                                                <label for="" class="control-label text-sm text-secondary mb-1">Status *</label>
                                                <select name="statusCategory" class="form-control form-control-sm" required>
                                                    <option {{ $item->status_category === 'OPEN' ? 'selected' : '' }} value="OPEN">Open</option>
                                                    <option {{ $item->status_category === 'CLOSED' ? 'selected' : '' }} value="CLOSED">Closed</option>
                                                </select>
                                            </div>
                                            <div class="mb-2">
                                                <input type="text" class="form-control form-control-sm" name="statusMemo" value="" placeholder="Memo">
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </span>
                                    </td>
                                    <td class="px-2">
                                        {{$item->facility ? $item->facility->name : ''}}
                                        <span moe>
                                        <a start show class="on-hover-opaque"><i class="fa fa-edit"></i></a>
                                        <form url="/api/actionItem/updateToFacility">
                                            <input type="hidden" name="uid" value="{{ $item->uid }}">
                                            <div class="mb-2">
                                                <label for="" class="control-label text-sm text-secondary mb-1">Facility *</label>
                                                <select name="toFacilityUid" class="form-control form-control-sm" required>
                                                    <option value="">-- Facility --</option>
                                                    @foreach ($facilities as $facility)
                                                        <option {{ $item->to_facility_id === $facility->id ? 'selected' : '' }} value="{{$facility->uid}}">{{$facility->name}}</option>
                                                    @endforeach
                                                </select>
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <button class="btn btn-sm btn-primary mr-2" submit>Save</button>
                                                <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </span>
                                    </td>
                                    <td class="px-2 text-center">
                                        <div class="d-flex align-items-center justify-content-start">
                                            @if($item->is_signed_by_prescriber)
                                                <span class="text-secondary">
                                            <i class="fa fa-check"></i>
                                            Signed
                                        </span>
                                                <span class="mx-2 text-secondary">|</span>
                                            @else
                                                @if($pro->id === $item->prescriber_pro_id)
                                                    <span moe relative>
                                                <a start show>Sign</a>
                                                <form url="/api/actionItem/signAsPrescriber" right>
                                                    <input type="hidden" name="uid" value="{{ $item->uid }}">
                                                    <p class="small min-width-200px text-left">Sign this action items as the prescriber?</p>
                                                    <div class="d-flex align-items-center">
                                                        <button class="btn btn-sm btn-success mr-2" submit>Yes</button>
                                                        <button class="btn btn-sm btn-default mr-2 border" cancel>No</button>
                                                    </div>
                                                </form>
                                            </span>
                                                    <span class="mx-2 text-secondary">|</span>
                                                @endif
                                            @endif
                                            <span moe relative>
                                        <a start show>eFax</a>
                                        <form url="/api/actionItem/efax" right>
                                            <input type="hidden" name="uid" value="{{ $item->uid }}">
                                            <div class="mb-2">
                                                <input type="text" class="form-control form-control-sm" name="toFaxNumber" value="" placeholder="To Number *" required>
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <button class="btn btn-sm btn-primary mr-2" submit>Send</button>
                                                <button class="btn btn-sm btn-default mr-2 border" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </span>
                                        </div>
                                    </td>
                                </tr>
                            @endif
                        @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

    </div>
    <script>
        (function() {
            function init() {
                $('input[type="text"][name="ICD"]').each(function() {
                    var elem = this, dynID = 'icd-' + Math.ceil(Math.random() * 1000000);
                    $(elem).attr('id', dynID);
                    new window.Def.Autocompleter.Search(dynID,
                        'https://clinicaltables.nlm.nih.gov/api/icd10cm/v3/search?sf=code,name&ef=name',
                        {
                            tableFormat: true,
                            valueCols: [0],
                            colHeaders: ['Code', 'Name'],
                        }
                    );
                    window.Def.Autocompleter.Event.observeListSelections(dynID, function() {
                        var autocomp = elem.autocomp;
                        var name = autocomp.getSelectedItemData()[0].data['name'];
                        $(elem).closest('form').find('[name="contentText"]').val(name);
                        return false;
                    });
                });
                $('[rx-section] input[type="text"][name="contentText"]').each(function() {
                    var elem = this, dynID = 'rx-' + Math.ceil(Math.random() * 1000000);
                    $(elem).attr('id', dynID);
                    var strengthElem = $(elem).closest('form').find('[name="strength"]')[0],
                        dynStrengthsID = 'rx-' + Math.ceil(Math.random() * 1000000) + '-strengths';
                    $(strengthElem).attr('id', dynStrengthsID);
                    new window.Def.Autocompleter.Prefetch(dynStrengthsID, []);
                    new window.Def.Autocompleter.Search(dynID,
                        'https://clinicaltables.nlm.nih.gov/api/rxterms/v3/search?ef=STRENGTHS_AND_FORMS');
                    window.Def.Autocompleter.Event.observeListSelections(dynID, function() {
                        var autocomp = elem.autocomp;
                        var strengths =
                            autocomp.getSelectedItemData()[0].data['STRENGTHS_AND_FORMS'];
                        if (strengths)
                            strengthElem.autocomp.setListAndField(strengths, '');
                    });
                });
            }
            addMCInitializer('patient-single', init);
        })();
    </script>
@endsection
